/*
                       Endeavour Recycle Bin Sync

	Compacts the recycled objects and fixes errors in the Recycle
	Bin.
 */

#ifndef EDVRECBINSYNC_H
#define EDVRECBINSYNC_H

#include <gtk/gtk.h>

#include "edv_types.h"
#include "edv_recycled_obj.h"


extern gint EDVRecBinSync(
	edv_core_struct *core,
	GtkWidget *toplevel,
	const gboolean show_progress, const gboolean interactive,
	gboolean *yes_to_all,
	void (*status_message_cb)(
		const gchar *,		/* Message */
		gpointer		/* Data */
	),
	gpointer status_message_data,
	void (*status_progress_cb)(
		gfloat,			/* Progress */
		gpointer		/* Data */
	),
	gpointer status_progress_data
);


#endif	/* EDVRECBINSYNC_H */
